@@ -38,8 +38,10 @@ Color options:
     color_bad: no IPs to show
     color_good: IPs to show
 
-Example:
+Requires:
+    ip: utility found in iproute2 package
 
+Examples:
 ```
 net_iplist {
     iface_blacklist = []
@@ -47,9 +49,6 @@ net_iplist {
 }
 ```
 
-Requires:
-    ip: utility found in iproute2 package
-
 @author guiniol
 
 SAMPLE OUTPUT
@@ -65,26 +64,27 @@ from fnmatch import fnmatch
 class Py3status:
     """
     """
+
     # available configuration parameters
     cache_timeout = 30
-    format = 'Network: {format_iface}'
-    format_iface = '{iface}:[ {ip4}][ {ip6}]'
-    format_no_ip = 'no connection'
-    iface_blacklist = ['lo']
-    iface_sep = ' '
+    format = "Network: {format_iface}"
+    format_iface = "{iface}:[ {ip4}][ {ip6}]"
+    format_no_ip = "no connection"
+    iface_blacklist = ["lo"]
+    iface_sep = " "
     ip_blacklist = []
-    ip_sep = ','
+    ip_sep = ","
     remove_empty = True
 
     def post_config_hook(self):
-        self.iface_re = re.compile(r'\d+: (?P<iface>\w+):')
-        self.ip_re = re.compile(r'\s+inet (?P<ip4>[\d\.]+)(?:/| )')
-        self.ip6_re = re.compile(r'\s+inet6 (?P<ip6>[\da-f:]+)(?:/| )')
+        self.iface_re = re.compile(r"\d+: (?P<iface>\w+):")
+        self.ip_re = re.compile(r"\s+inet (?P<ip4>[\d\.]+)(?:/| )")
+        self.ip6_re = re.compile(r"\s+inet6 (?P<ip6>[\da-f:]+)(?:/| )")
 
-    def ip_list(self):
+    def net_iplist(self):
         response = {
-            'cached_until': self.py3.time_in(seconds=self.cache_timeout),
-            'full_text': ''
+            "cached_until": self.py3.time_in(seconds=self.cache_timeout),
+            "full_text": "",
         }
 
         connection = False
@@ -96,53 +96,63 @@ class Py3status:
 
             ip4_list = []
             ip6_list = []
-            for ip4 in ips.get('ip4', []):
+            for ip4 in ips.get("ip4", []):
                 if self._check_blacklist(ip4, self.ip_blacklist):
                     connection = True
                     ip4_list.append(ip4)
-            for ip6 in ips.get('ip6', []):
+            for ip6 in ips.get("ip6", []):
                 if self._check_blacklist(ip6, self.ip_blacklist):
                     connection = True
                     ip6_list.append(ip6)
-            iface_list.append(self.py3.safe_format(self.format_iface,
-                                                   {'iface': iface,
-                                                    'ip4': self.ip_sep.join(ip4_list),
-                                                    'ip6': self.ip_sep.join(ip6_list)}))
+            iface_list.append(
+                self.py3.safe_format(
+                    self.format_iface,
+                    {
+                        "iface": iface,
+                        "ip4": self.ip_sep.join(ip4_list),
+                        "ip6": self.ip_sep.join(ip6_list),
+                    },
+                )
+            )
         if not connection:
-            response['full_text'] = self.py3.safe_format(self.format_no_ip,
-                                                         {'format_iface':
-                                                             self.py3.composite_join(
-                                                                 self.iface_sep, iface_list)})
-            response['color'] = self.py3.COLOR_BAD
+            response["full_text"] = self.py3.safe_format(
+                self.format_no_ip,
+                {"format_iface": self.py3.composite_join(self.iface_sep, iface_list)},
+            )
+            response["color"] = self.py3.COLOR_BAD
         else:
-            response['full_text'] = self.py3.safe_format(self.format,
-                                                         {'format_iface':
-                                                             self.py3.composite_join(
-                                                                 self.iface_sep, iface_list)})
-            response['color'] = self.py3.COLOR_GOOD
+            response["full_text"] = self.py3.safe_format(
+                self.format,
+                {"format_iface": self.py3.composite_join(self.iface_sep, iface_list)},
+            )
+            response["color"] = self.py3.COLOR_GOOD
 
         return response
 
     def _get_data(self):
-        txt = self.py3.command_output(['ip', 'address', 'show']).splitlines()
+        txt = self.py3.command_output(["ip", "address", "show"]).splitlines()
 
         data = {}
         for line in txt:
             iface = self.iface_re.match(line)
             if iface:
-                cur_iface = iface.group('iface')
+                cur_iface = iface.group("iface")
                 if not self.remove_empty:
                     data[cur_iface] = {}
                 continue
 
             ip4 = self.ip_re.match(line)
             if ip4:
-                data.setdefault(cur_iface, {}).setdefault('ip4', []).append(ip4.group('ip4'))
+                data.setdefault(cur_iface, {}).setdefault("ip4", []).append(
+                    ip4.group("ip4")
+                )
                 continue
 
             ip6 = self.ip6_re.match(line)
             if ip6:
-                data.setdefault(cur_iface, {}).setdefault('ip6', []).append(ip6.group('ip6'))
+                data.setdefault(cur_iface, {}).setdefault("ip6", []).append(
+                    ip6.group("ip6")
+                )
                 continue
 
         return data
@@ -159,4 +169,5 @@ if __name__ == "__main__":
     Test this module by calling it directly.
     """
     from py3status.module_test import module_test
+
     module_test(Py3status)
