@@ -19,7 +19,6 @@ Configuration parameters:
     icon_on: what to display when online (default '●')
     mode: default mode to display is 'ip' or 'status' (click to toggle)
         (default 'ip')
-    timeout: how long before deciding we're offline (default 5)
     url_geo: IP to check for geo location (must output json)
         (default 'https://ifconfig.co/json')
 
@@ -51,48 +50,47 @@ mode
 
 from time import time
 
-URL_GEO_OLD_DEFAULT = 'http://ip-api.com/json'
-URL_GEO_NEW_DEFAULT = 'https://ifconfig.co/json'
+URL_GEO_OLD_DEFAULT = "http://ip-api.com/json"
+URL_GEO_NEW_DEFAULT = "https://ifconfig.co/json"
 
 
 class Py3status:
     """
     """
+
     # available configuration parameters
     button_refresh = 2
     button_toggle = 1
     cache_timeout = 60
     expected = None
-    format = '{ip}'
+    format = "{ip}"
     hide_when_offline = False
-    icon_off = u'■'
-    icon_on = u'●'
-    mode = 'ip'
-    timeout = 5
+    icon_off = u"■"
+    icon_on = u"●"
+    mode = "ip"
     url_geo = URL_GEO_NEW_DEFAULT
 
     class Meta:
         deprecated = {
-            'remove': [
-                {
-                    'param': 'url',
-                    'msg': 'obsolete parameter, use `url_geo` instead',
-                },
-                {
-                    'param': 'negative_cache_timeout',
-                    'msg': 'obsolete parameter',
-                },
+            "remove": [
+                {"param": "url", "msg": "obsolete parameter, use `url_geo` instead"},
+                {"param": "negative_cache_timeout", "msg": "obsolete parameter"},
             ],
-            'rename': [
+            "rename": [
                 {
-                    'param': 'format_online',
-                    'new': 'icon_on',
-                    'msg': 'obsolete parameter, use `icon_on` instead',
+                    "param": "format_online",
+                    "new": "icon_on",
+                    "msg": "obsolete parameter, use `icon_on` instead",
                 },
                 {
-                    'param': 'format_offline',
-                    'new': 'icon_off',
-                    'msg': 'obsolete parameter, use `icon_off` instead',
+                    "param": "format_offline",
+                    "new": "icon_off",
+                    "msg": "obsolete parameter, use `icon_off` instead",
+                },
+                {
+                    "param": "timeout",
+                    "new": "request_timeout",
+                    "msg": "obsolete parameter use `request_timeout`",
                 },
             ],
         }
@@ -104,9 +102,9 @@ class Py3status:
         # Backwards compatibility
         self.substitutions = {}
         if self.url_geo == URL_GEO_NEW_DEFAULT:
-            self.substitutions['country_code'] = 'country_iso'
+            self.substitutions["country_code"] = "country_iso"
         elif self.url_geo == URL_GEO_OLD_DEFAULT:
-            self.substitutions['ip'] = 'query'
+            self.substitutions["ip"] = "query"
 
         self.ip_data = {}
         self.toggled = False
@@ -114,7 +112,7 @@ class Py3status:
 
     def _get_my_ip_info(self):
         try:
-            info = self.py3.request(self.url_geo, timeout=self.timeout).json()
+            info = self.py3.request(self.url_geo).json()
             for old, new in self.substitutions.items():
                 info[old] = info.get(new)
             return info
@@ -140,24 +138,24 @@ class Py3status:
         else:
             info = self.ip_data = self._get_my_ip_info()
 
-        response = {'cached_until': self.py3.time_in(cached_until)}
+        response = {"cached_until": self.py3.time_in(cached_until)}
 
         if info is None and self.hide_when_offline:
-            response['full_text'] = ''
+            response["full_text"] = ""
         elif info is not None:
-            info['icon'] = self.icon_on
-            response['color'] = self.py3.COLOR_GOOD
+            info["icon"] = self.icon_on
+            response["color"] = self.py3.COLOR_GOOD
             for key, val in self.expected.items():
                 if val != info.get(key):
-                    response['color'] = self.py3.COLOR_DEGRADED
+                    response["color"] = self.py3.COLOR_DEGRADED
                     break
-            if self.mode == 'ip':
-                response['full_text'] = self.py3.safe_format(self.format, info)
+            if self.mode == "ip":
+                response["full_text"] = self.py3.safe_format(self.format, info)
             else:
-                response['full_text'] = self.icon_on
+                response["full_text"] = self.icon_on
         else:
-            response['full_text'] = self.icon_off
-            response['color'] = self.py3.COLOR_BAD
+            response["full_text"] = self.icon_off
+            response["color"] = self.py3.COLOR_BAD
 
         return response
 
@@ -165,13 +163,13 @@ class Py3status:
         """
         Toggle between display modes 'ip' and 'status'
         """
-        button = event['button']
+        button = event["button"]
         if button == self.button_toggle:
             self.toggled = True
-            if self.mode == 'ip':
-                self.mode = 'status'
+            if self.mode == "ip":
+                self.mode = "status"
             else:
-                self.mode = 'ip'
+                self.mode = "ip"
         elif button == self.button_refresh:
             self.idle_time = 0
         else:
@@ -183,4 +181,5 @@ if __name__ == "__main__":
     Run module in test mode.
     """
     from py3status.module_test import module_test
+
     module_test(Py3status)
