@@ -26,6 +26,28 @@ Configuration parameters:
         and want to automatically fallback to your laptop screen when you
         disconnect the external screen. (default True)
     fixed_width: show output as fixed width (default True)
+    force_on_change: switch display layout to the leftmost combination mode
+        of the given list whenever it is available. The combination modes are
+        checked from left (high priority) to right (less priority) until
+        one matches.
+        Example:
+            We have a laptop with internal screen and we are often moving from
+            our desk where another screen is available. We want the layout to
+            follow our changes so that we do not have to switch manually.
+            So whenever we plug at our desk, we want the second monitor to be
+            used, and whenever we go away we want everything back on the laptop
+            screen automatically:
+            ```
+            force_on_change = ["eDP1+DP1", "eDP1"]
+            ```
+        NOTES:
+            Click controls will override `force_on_change` until the layout
+            changes in the background so you can still manually control your
+            layout changes on the bar.
+            Use the `force_on_start` to handle initial layout setup on module
+            startup along with this feature to benefit from fully dynamic and
+            automated changes of screen layouts.
+        (default [])
     force_on_start: switch to the given combination mode if available
         when the module starts (saves you from having to configure xorg)
         (default None)
@@ -58,6 +80,8 @@ Configuration parameters:
         (default None)
 
 Dynamic configuration parameters:
+    <OUTPUT>_icon: use this icon instead of OUTPUT name as text
+        Example: DP1_icon = "🖵"
     <OUTPUT>_pos: apply the given position to the OUTPUT
         Example: DP1_pos = "-2560x0"
         Example: DP1_pos = "above eDP1"
@@ -70,8 +94,13 @@ Dynamic configuration parameters:
     <OUTPUT>_rotate: rotate the output as told
         Example: DP1_rotate = "left"
     <OUTPUT>_mode: define the mode (resolution) for the output
-                   if not specified use --auto : prefered mode
+                   if not specified use --auto : preferred mode
         Example: eDP1_mode = "2560x1440
+    <OUTPUT>_primary: apply the primary to the OUTPUT
+        Example: DP1_primary = True
+
+Format placeholders:
+    {output} xrandr output
 
 Color options:
     color_bad: Displayed layout unavailable
@@ -100,17 +129,16 @@ xrandr {
 @author ultrabug
 
 SAMPLE OUTPUT
-{'color': '#00FF00', 'full_text': u'LVDS1'}
-
-extend
 {'color': '#00FF00', 'full_text': 'LVDS1+DP1'}
 
 mirror
-{'color': '#00FF00', 'full_text': 'LVDS1=DP1'}
+{'full_text': 'LVDS1=DP1'}
 
-single
-{'color': '#00FF00', 'full_text': 'DP1'}
+single_1
+{'full_text': u'LVDS1'}
 
+single_2
+{'full_text': 'DP1'}
 """
 
 from collections import deque
@@ -122,42 +150,45 @@ from time import sleep
 class Py3status:
     """
     """
+
     # available configuration parameters
     cache_timeout = 10
     command = None
     fallback = True
     fixed_width = True
+    force_on_change = []
     force_on_start = None
-    format = '{output}'
+    format = "{output}"
     hide_if_single_combination = False
-    icon_clone = '='
-    icon_extend = '+'
-    on_udev_drm = 'refresh_and_freeze'
+    icon_clone = "="
+    icon_extend = "+"
+    on_udev_drm = "refresh_and_freeze"
     output_combinations = None
 
     class Meta:
         deprecated = {
-            'rename': [
+            "rename": [
                 {
-                    'param': 'format_clone',
-                    'new': 'icon_clone',
-                    'msg': 'obsolete parameter use `icon_clone`',
+                    "param": "format_clone",
+                    "new": "icon_clone",
+                    "msg": "obsolete parameter use `icon_clone`",
                 },
                 {
-                    'param': 'format_extend',
-                    'new': 'icon_extend',
-                    'msg': 'obsolete parameter use `icon_extend`',
+                    "param": "format_extend",
+                    "new": "icon_extend",
+                    "msg": "obsolete parameter use `icon_extend`",
                 },
-            ],
+            ]
         }
 
     def post_config_hook(self):
         """
         Initialization
         """
+        self._no_force_on_change = True
         self.active_comb = None
         self.active_layout = None
-        self.active_mode = 'extend'
+        self.active_mode = "extend"
         self.displayed = None
         self.max_width = 0
 
@@ -169,28 +200,27 @@ class Py3status:
         connected = list()
         active_layout = list()
         disconnected = list()
-        layout = OrderedDict({
-            'connected': OrderedDict(),
-            'disconnected': OrderedDict()
-        })
+        layout = OrderedDict(
+            {"connected": OrderedDict(), "disconnected": OrderedDict()}
+        )
 
-        current = self.py3.command_output('xrandr')
+        current = self.py3.command_output("xrandr")
         for line in current.splitlines():
             try:
-                s = line.split(' ')
-                infos = line[line.find('('):]
-                if s[1] == 'connected':
+                s = line.split(" ")
+                infos = line[line.find("(") :]
+                if s[1] == "connected":
                     output, state, mode = s[0], s[1], None
                     for index, x in enumerate(s[2:], 2):
-                        if 'x' in x and '+' in x:
+                        if "x" in x and "+" in x:
                             mode = x
                             active_layout.append(output)
-                            infos = line[line.find(s[index + 1]):]
+                            infos = line[line.find(s[index + 1]) :]
                             break
-                        elif '(' in x:
+                        elif "(" in x:
                             break
                     connected.append(output)
-                elif s[1] == 'disconnected':
+                elif s[1] == "disconnected":
                     output, state, mode = s[0], s[1], None
                     disconnected.append(output)
                 else:
@@ -198,17 +228,14 @@ class Py3status:
             except Exception as err:
                 self.py3.log('xrandr error="{}"'.format(err))
             else:
-                layout[state][output] = {
-                    'infos': infos,
-                    'mode': mode,
-                    'state': state
-                }
+                layout[state][output] = {"infos": infos, "mode": mode, "state": state}
 
         # initialize the active layout
         if self.active_layout is None:
             self.active_comb = tuple(active_layout)
             self.active_layout = self._get_string_and_set_width(
-                tuple(active_layout), self.active_mode)
+                tuple(active_layout), self.active_mode
+            )
 
         return layout
 
@@ -222,12 +249,12 @@ class Py3status:
 
         whitelist = None
         if self.output_combinations:
-            whitelist = self.output_combinations.split('|')
+            whitelist = self.output_combinations.split("|")
 
         self.max_width = 0
-        for output in range(len(self.layout['connected'])):
-            for comb in combinations(self.layout['connected'], output + 1):
-                for mode in ['clone', 'extend']:
+        for output in range(len(self.layout["connected"])):
+            for comb in combinations(self.layout["connected"], output + 1):
+                for mode in ["clone", "extend"]:
                     string = self._get_string_and_set_width(comb, mode)
                     if whitelist and string not in whitelist:
                         continue
@@ -239,8 +266,7 @@ class Py3status:
 
         # Preserve the order in which user defined the output combinations
         if whitelist:
-            available = reversed([comb for comb in whitelist
-                                  if comb in available])
+            available = reversed([comb for comb in whitelist if comb in available])
 
         self.available_combinations = deque(available)
         self.combinations_map = combinations_map
@@ -249,8 +275,9 @@ class Py3status:
         """
         Construct the string to be displayed and record the max width.
         """
-        show = '{}'.format(self._separator(mode)).join(combination)
-        show = show.rstrip('{}'.format(self._separator(mode)))
+        show = getattr(self, "icon_{}".format(mode)).join(
+            tuple(getattr(self, "{}_icon".format(x), x) for x in combination)
+        )
         self.max_width = max([self.max_width, len(show)])
         return show
 
@@ -262,8 +289,10 @@ class Py3status:
         we display the last selected combination.
         """
         for _ in range(len(self.available_combinations)):
-            if (self.displayed is None and
-                    self.available_combinations[0] == self.active_layout):
+            if (
+                self.displayed is None
+                and self.available_combinations[0] == self.active_layout
+            ):
                 self.displayed = self.available_combinations[0]
                 break
             else:
@@ -275,14 +304,13 @@ class Py3status:
             if force_refresh:
                 self.displayed = self.available_combinations[0]
             else:
-                self.py3.log(
-                    'xrandr error="displayed combination is not available"')
+                self.py3.log('xrandr error="displayed combination is not available"')
 
     def _center(self, s):
         """
         Center the given string on the detected max width.
         """
-        fmt = '{:^%d}' % self.max_width
+        fmt = "{:^%d}" % self.max_width
         return fmt.format(s)
 
     def _apply(self, force=False):
@@ -293,44 +321,49 @@ class Py3status:
             # no change, do nothing
             return
 
-        combination, mode = self.combinations_map.get(self.displayed,
-                                                      (None, None))
+        combination, mode = self.combinations_map.get(self.displayed, (None, None))
         if combination is None and mode is None:
             # displayed combination cannot be activated, ignore
             return
 
-        cmd = 'xrandr'
-        outputs = list(self.layout['connected'].keys())
-        outputs += list(self.layout['disconnected'].keys())
+        cmd = "xrandr"
+        outputs = list(self.layout["connected"].keys())
+        outputs += list(self.layout["disconnected"].keys())
         previous_output = None
+        primary_added = False
         for output in outputs:
-            cmd += ' --output {}'.format(output)
+            cmd += " --output {}".format(output)
             #
             if output in combination:
-                pos = getattr(self, '{}_pos'.format(output), '0x0')
-                rotation = getattr(self, '{}_rotate'.format(output), 'normal')
-                resolution = getattr(self, '{}_mode'.format(output), None)
-                resolution = '--mode {}'.format(resolution) if resolution else '--auto'
-                if rotation not in ['inverted', 'left', 'normal', 'right']:
-                    self.py3.log('configured rotation {} is not valid'.format(
-                        rotation))
-                    rotation = 'normal'
+                pos = getattr(self, "{}_pos".format(output), "0x0")
+                primary = getattr(self, "{}_primary".format(output), None)
+                resolution = getattr(self, "{}_mode".format(output), None)
+                resolution = "--mode {}".format(resolution) if resolution else "--auto"
+                rotation = getattr(self, "{}_rotate".format(output), "normal")
+                if rotation not in ["inverted", "left", "normal", "right"]:
+                    self.py3.log("configured rotation {} is not valid".format(rotation))
+                    rotation = "normal"
                 #
-                if mode == 'clone' and previous_output is not None:
-                    cmd += ' {} --same-as {}'.format(resolution,
-                                                     previous_output)
+                if primary is True and not primary_added:
+                    primary_added = True
+                    cmd += " --primary"
+                if mode == "clone" and previous_output is not None:
+                    cmd += " {} --same-as {}".format(resolution, previous_output)
                 else:
-                    if ('above' in pos or 'below' in pos or 'left-of' in pos or
-                            'right-of' in pos):
-                        cmd += ' {} --{} --rotate {}'.format(resolution, pos,
-                                                             rotation)
+                    if (
+                        "above" in pos
+                        or "below" in pos
+                        or "left-of" in pos
+                        or "right-of" in pos
+                    ):
+                        cmd += " {} --{} --rotate {}".format(resolution, pos, rotation)
                     else:
-                        cmd += ' {} --pos {} --rotate {}'.format(resolution,
-                                                                 pos,
-                                                                 rotation)
+                        cmd += " {} --pos {} --rotate {}".format(
+                            resolution, pos, rotation
+                        )
                 previous_output = output
             else:
-                cmd += ' --off'
+                cmd += " --off"
         #
         code = self.py3.command_run(cmd)
         if code == 0:
@@ -353,23 +386,27 @@ class Py3status:
         Example:
             - DP1_workspaces = "1,2,3"
         """
-        if len(combination) > 1 and mode == 'extend':
+        if len(combination) > 1 and mode == "extend":
             sleep(3)
             for output in combination:
-                workspaces = getattr(self, '{}_workspaces'.format(output),
-                                     '').split(',')
+                workspaces = getattr(self, "{}_workspaces".format(output), "").split(
+                    ","
+                )
                 for workspace in workspaces:
                     if not workspace:
                         continue
                     # switch to workspace
-                    cmd = 'i3-msg workspace "{}"'.format(workspace)
+                    cmd = '{} workspace "{}"'.format(self.py3.get_wm_msg(), workspace)
                     self.py3.command_run(cmd)
                     # move it to output
-                    cmd = 'i3-msg move workspace to output "{}"'.format(output)
+                    cmd = '{} move workspace to output "{}"'.format(
+                        self.py3.get_wm_msg(), output
+                    )
                     self.py3.command_run(cmd)
                     # log this
-                    self.py3.log('moved workspace {} to output {}'.format(
-                        workspace, output))
+                    self.py3.log(
+                        "moved workspace {} to output {}".format(workspace, output)
+                    )
 
     def _fallback_to_available_output(self):
         """
@@ -391,24 +428,29 @@ class Py3status:
         """
         if self.force_on_start in self.available_combinations:
             self.displayed = self.force_on_start
-            self.force_on_start = None
             self._choose_what_to_display(force_refresh=True)
             self._apply(force=True)
             self.py3.update()
-
-    def _separator(self, mode):
-        """
-        Return the separator for the given mode.
-        """
-        if mode == 'extend':
-            return self.icon_extend
-        if mode == 'clone':
-            return self.icon_clone
+        self.force_on_start = None
 
     def _switch_selection(self, direction):
         self.available_combinations.rotate(direction)
         self.displayed = self.available_combinations[0]
 
+    def _force_on_change(self):
+        """
+        Handle force_on_change feature.
+        """
+        for layout in self.force_on_change:
+            if layout in self.available_combinations:
+                if self.active_layout != layout:
+                    self.displayed = layout
+                    self._apply(force=True)
+                    self.py3.update()
+                    break
+                else:
+                    break
+
     def on_click(self, event):
         """
         Click events
@@ -416,7 +458,8 @@ class Py3status:
             - right click: apply selected mode
             - middle click: force refresh of available modes
         """
-        button = event['button']
+        self._no_force_on_change = True
+        button = event["button"]
         if button == 4:
             self._switch_selection(-1)
         if button in [1, 5]:
@@ -435,35 +478,42 @@ class Py3status:
         self._set_available_combinations()
         self._choose_what_to_display()
 
-        if (len(self.available_combinations) < 2 and
-                self.hide_if_single_combination):
-            full_text = self.py3.safe_format(self.format, {'output': ''})
+        if len(self.available_combinations) < 2 and self.hide_if_single_combination:
+            full_text = self.py3.safe_format(self.format, {"output": ""})
         else:
             if self.fixed_width is True:
                 output = self._center(self.displayed)
             else:
                 output = self.displayed
-            full_text = self.py3.safe_format(self.format, {'output': output})
+            full_text = self.py3.safe_format(self.format, {"output": output})
 
         response = {
-            'cached_until': self.py3.time_in(self.cache_timeout),
-            'full_text': full_text
+            "cached_until": self.py3.time_in(self.cache_timeout),
+            "full_text": full_text,
         }
 
         # coloration
         if self.displayed == self.active_layout:
-            response['color'] = self.py3.COLOR_GOOD
+            response["color"] = self.py3.COLOR_GOOD
         elif self.displayed not in self.available_combinations:
-            response['color'] = self.py3.COLOR_BAD
+            response["color"] = self.py3.COLOR_BAD
 
-        # force default layout setup
+        # force default layout setup at module startup
         if self.force_on_start is not None:
             sleep(1)
             self._force_force_on_start()
 
+        # follow on change
+        if not self._no_force_on_change and self.force_on_change:
+            self._force_on_change()
+
+        # this was a click event triggered update
+        if self._no_force_on_change:
+            self._no_force_on_change = False
+
         # fallback detection
         if self.active_layout not in self.available_combinations:
-            response['color'] = self.py3.COLOR_DEGRADED
+            response["color"] = self.py3.COLOR_DEGRADED
             if self.fallback is True:
                 self._fallback_to_available_output()
 
@@ -475,4 +525,5 @@ if __name__ == "__main__":
     Run module in test mode.
     """
     from py3status.module_test import module_test
+
     module_test(Py3status)
